@@ -1,5 +1,4 @@
-#! /usr/bin/python2
-# -*- coding: utf-8; -*-
+#! /usr/bin/python3
 #
 # dput/dput.py
 # Part of ‘dput’, a Debian package upload toolkit.
@@ -10,9 +9,12 @@
 
 """ dput — Debian package upload tool. """
 
-import ConfigParser
+import configparser
 import email.parser
-from hashlib import md5, sha1
+from hashlib import (
+        md5,
+        sha1,
+        )
 import importlib
 import os
 import os.path
@@ -101,7 +103,7 @@ def read_configs(extra_config, debug):
         The config parser will layer values.
 
         """
-    config = ConfigParser.ConfigParser()
+    config = configparser.ConfigParser()
 
     config.set('DEFAULT', 'login', 'username')
     config.set('DEFAULT', 'method', 'scp')
@@ -139,8 +141,8 @@ def read_configs(extra_config, debug):
             sys.stdout.write(
                     "D: Parsing Configuration File %s\n" % config_file)
         try:
-            config.readfp(fd)
-        except ConfigParser.ParsingError as e:
+            config.read_file(fd)
+        except configparser.ParsingError as e:
             sys.stderr.write("Error parsing config file:\n%s\n" % str(e))
             sys.exit(1)
         fd.close()
@@ -364,7 +366,7 @@ def verify_files(
     try:
         if config.getboolean(host, 'check_version') == 1 or check_version:
             version_check(path, changes, debug)
-    except ConfigParser.NoSectionError as e:
+    except configparser.NoSectionError as e:
         sys.stderr.write("Error in config file:\n%s\n" % str(e))
         sys.exit(1)
 
@@ -968,7 +970,7 @@ def main():
                 sys.stdout.write("D: Host %s found in config.\n" % args[0])
                 preferred_host = args[0]
                 package_to_upload = args[1:]
-            elif not config.has_section(args[0]):
+            else:
                 sys.stdout.write("D: No host %s found in config\n" % args[0])
                 package_to_upload = args[0:]
 
@@ -1112,7 +1114,8 @@ def main():
                 progress = 0
             if method == 'ftp':
                 if ':' in fqdn:
-                    fqdn, port = fqdn.rsplit(":", 1)
+                    fqdn, port_text = fqdn.rsplit(":", 1)
+                    port = int(port_text)
                 else:
                     port = 21
                 ftp_mode = config.getboolean(host, 'passive_ftp')
@@ -1202,24 +1205,23 @@ if __name__ == '__main__':
         sys.exit(1)
 
 
-# Copyright © 2015–2016 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2018 Ben Finney <bignose@debian.org>
 # Copyright © 2008–2013 Y Giridhar Appaji Nag <appaji@debian.org>
 # Copyright © 2006–2008 Thomas Viehmann <tv@beamnet.de>
 # Copyright © 2000–2005 Christian Kurz <shorty@debian.org>
 #
-# This program is free software; you can redistribute it and/or modify
+# This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
 
 
 # Local variables:
